;
;   Versione per AUTOCAD 12 o Superiore  I T A L I A N O / I N G L E S E
;
;
;      _________________________________________________________________
;      |                                                               |
;      |   ACQUISIZIONE DEI DATI CON L'UTILIZZO DI SUBRURINE           |
;      |                                                               |
;      |                                                               | 
;      |                                                               |
;      
;
;
;---------------------------------
;  Input Variabili ambiente
;---------------------------------
(defun MODES (a)
   (setq mlst '())				; Inizializza lista (lista vuota)
   (repeat (length a)				; Ripete per tutta la lunghezza della lista
      (setq mlst (append mlst (list (list (car a) (getvar (car a))))))
      (setq a (cdr a))				; Accorcia lista eliminando primo elemento
   )
)
;-----------------------------------
;  Ripristina variabili ambiente
;-----------------------------------
(defun MODER ()
   (repeat (length mlst)			; Ripete per tutta la lunghezza della lista
      (setvar (caar mlst) (cadar mlst))		; Estrae ed imposta "nome variabile" e valore
      (setq mlst (cdr mlst))			; Accorcia lista eliminando primo elemento
   )
)
; ----------------------------------
; Error handler (gestione errore)
; ----------------------------------
(defun b_err (st)
  (moder)					; Ripristina variabili memorizzate
  (setq *error* olderr)				; Restore old *error* handler

;;;;  Inserire qui altre variabili di sistema o comandi da eseguire prima dell'uscita

  (princ)					; Esce senza nil
)
;
;-----------------------------
;	SCELTAS (Stringa)
;-----------------------------
;	msg	= Stringa domanda		- es. "\nCosa scegli <"
;	def	= Valore default		- es. "S"
;	msg1	= Stringa fine domanda		- es. "> ? "
;	nul	= se=0 non accetta risposta nulla se=1 accetta anche un invio
;	opzioni = stringa possibili risposte	- es. "S N"
;
;	La variabile in uscita e' SCELTA (stringa)
;
;
(defun SCELTAS (msg def msg1 nul opzioni)
;
   (initget nul opzioni)			; Risposte accettate
   (prompt msg)					; Messaggio di richiesta
   (prin1 def)					; Valore di default
   (setq scelta (getkword msg1))		; Assegnazione valore alla variabile
;
   (if (= scelta nil)				; Premendo INVIO (scelta nulla) ...
	(setq scelta def)			; ... si accetta il default ...
   )						; Fine di IF scelta
;
)
;
;------------------------------------------
;	SCELTAN (Numero Reale o Intero)
;------------------------------------------
;	intrea	= 1=N.Intero (es. 20) - 0=N.reale (es. 20.5)
;	msg	= Stringa domanda		- es. "\nInserisci numero <"
;	def	= Valore default		- es. 5
;	msg1	= Stringa fine domanda		- es. "> ? "
;
;	La variabile in uscita e' SCELTA (N. Intero o Reale)
;
;
(defun SCELTAN (intrea msg def msg1)
;
   (prompt msg)					; Messaggio di richiesta
   (prin1 def)					; Valore di default
;
   (if (= intrea 1)
	(setq scelta (getint msg1))		; Assegnazione valore alla variabile (N. INTERO)
	(setq scelta (getreal msg1))		; Assegnazione valore alla variabile (N. REALE)
   )
;
   (if (= scelta nil)				; Premendo INVIO (scelta nulla) ...
	(setq scelta def)			; ... si accetta il default ...
   )						; Fine di IF scelta
;
)
;
;------------------------------------------
;	SELSING (Selez. entita' singola)
;------------------------------------------
;	entnent	= 0=entsel (entita') 1=nentsel (sottoentita')
;	msg	= Stringa domanda		- es. "\nSeleziona un'entita': "
;	lst	= Lista di codici di gruppo (vedi Help di Autocad)
;			Esempi :
;		CODICE			Significato
;		  0			Tipo di entita' (es. "TEXT" "INSERT" "CIRCLE" ...)
;		  8			Layer (es. "MURI")
;		  6			Tipo linea (es. "TRATTEGGIATA") nil se "dalayer"
;		 62			Colore (es. 1 = Rosso) nil se "Dalayer"
;		 41			Fattore di scala asse X (per i blocchi)
;
;	La variabile in uscita e' ENLST
;
;
(defun SELSING (entnent msg lst)
;
   (if (= entnent 0)
	(setq ent (entsel msg))			; Selezionata un'entita' (linea - cerchio - blocco)
	(setq ent (nentsel msg))		; Selez. entita' interna (es. linea all'interno di un blocco)
   )
;
   (setq lie (entget (car ent)))		; Estrae lista dell' entita' selezionata
;
   (setq enlst '())
   (repeat (length lst)
      (setq enlst (append enlst (list (assoc (car lst) lie))))
      (setq lst (cdr lst))			; Accorcia lista eliminando primo elemento
   )
;
)
;
;
;----------------------------
;        Input Dati
;----------------------------
(defun INDATI ()
;
   (graphscr)					; Passa allo schermo grafico (se si fosse in quello testo)
   (setvar "highlight" 1)			; Imposta ad "on" la visualizzaz. degli elem. selezionati
   (modes '("HIGHLIGHT" "OSMODE" "LIMCHECK" "CMDECHO")); Lista di variabili da ripristinare all'uscita
   (setvar "osmode" 0) (setvar "limcheck" 0)	; Variabili impostate ad "off"
   (setvar "cmdecho" 0)				; Idem
;
; - - - - - - - - - - - - - - - - - - - - - - - - - -
;	Richiamo Sub. Sceltas (variabile Stringa)
; - - - - - - - - - - - - - - - - - - - - - - - - - -
;
   (if (= cosadef nil)(setq cosadef "A")); Assegna un valore alla var. di default se e' nulla
   (SCELTAS "\nCosa Scegli (A/B) <" cosadef "> ? " 0 "A B");Richiamo sub.
   (setq cosadef scelta)			; Viene aggiorn. default
   (prompt "\nCosadef = ")(prin1 cosadef)	; Stampa il risultato sulla riga comando
;
; - - - - - - - - - - - - - - - - - - - - - - - - - -
;	Richiamo Sub. Sceltan (variabile N. Intero)
; - - - - - - - - - - - - - - - - - - - - - - - - - -
;
   (if (= numdef nil)(setq numdef "5"))		; Assegna un valore alla var. di default se e' nulla
   (SCELTAN 1 "\nInserisci un numero INTERO <" numdef "> ? ");Richiamo sub.
   (setq numdef scelta)				; Viene aggiorn. default
   (prompt "\nNumdef = ")(prin1 numdef)		; Stampa il risultato sulla riga comando
;
; - - - - - - - - - - - - - - - - - - - - - - - - - -
;	Richiamo Sub. Sceltan (variabile N. Reale)
; - - - - - - - - - - - - - - - - - - - - - - - - - -
;
   (if (= num1def nil)(setq num1def "5.5"))	; Assegna un valore alla var. di default se e' nulla
   (SCELTAN 0 "\nInserisci un numero REALE <" num1def "> ? ");Richiamo sub.
   (setq num1def scelta)			; Viene aggiorn. default
   (prompt "\nNum1def = ")(prin1 num1def)	; Stampa il risultato sulla riga comando
;
; - - - - - - - - - - - - - - - - - - - - - - - - - -
;	Richiamo Sub. Selsing (Selez. entita' singola)
; - - - - - - - - - - - - - - - - - - - - - - - - - -
;
   (SELSING 0 "\nSeleziona un'entita' qualunque: " '(0 8 41 6));Richiamo sub.
   (prompt "\nEnlst = ")(prin1 enlst)		; Stampa il risultato sulla riga comando
;
; - - - - - - - - - - - - - - - - - - - - - - - - - -
;	Richiamo Sub. Selsing (Selez. entita' singola interna ad un blocco)
; - - - - - - - - - - - - - - - - - - - - - - - - - -
;
   (SELSING 1 "\nSeleziona un blocco: " '(0 8 41 6));Richiamo sub.
   (prompt "\nEnlst = ")(prin1 enlst)		; Stampa il risultato sulla riga comando
;
)
;
;
;--------------------------------------------------
;     P R O G R A M M A     P R I N C I P A L E
;--------------------------------------------------
(defun C:TUTORIAL (/ a mlst)
;
   (setq olderr *error* *error* b_err)		; Richiama gestore errori
;
   (indati)					; Richiama sub. inserimento dati
;
;	Inserire qui il richiamo ad altre sub. o istruzioni
;
   (moder)					; Ripristina variabili a termine programma
;
   (setq olderr *error*)			; Ripristina in caso di errore
   (princ)					; Esce senza stampare nil su riga comando
)


